<?php

namespace Drupal\Tests\vgwort\Kernel\DataProducer;

use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\taxonomy\Entity\Term;
use Drupal\taxonomy\Entity\Vocabulary;
use Drupal\Tests\graphql\Kernel\GraphQLTestBase;

/**
 * Data producers EntityLinks test class.
 *
 * @group Thunder
 */
class VgWortDataProducerTest extends GraphQLTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'vgwort',
    'text',
    'taxonomy',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('taxonomy_term');

    NodeType::create([
      'type' => 'article',
      'name' => 'Article',
    ])->save();

    Vocabulary::create([
      'vid' => 'tags',
      'name' => 'tags',
    ])->save();

    $this->installConfig('vgwort');
  }

  /**
   * Tests basic data producer functionality.
   */
  public function testDataProducer(): void {
    $this->config('vgwort.settings')
      ->set('publisher_id', '12345678')
      ->set('image_domain', 'example.com')
      ->save();

    $node = Node::create([
      'title' => 'Title',
      'type' => 'article',
    ]);

    $node->save();

    $result = $this->executeDataProducer('vgwort', [
      'entity' => $node,
    ]);

    $this->assertNotNull($result);
    $this->assertEquals($node->vgwort_counter_id->value, $result['counterId']);
    $this->assertEquals($node->vgwort_counter_id->url, $result['url']);
    $this->assertEquals('<img src="\\\\' . $node->vgwort_counter_id->url . '" height="1" width="1" alt=""/>', $result['rendered']);

    // Test the test mode.
    $this->config('vgwort.settings')
      ->set('test_mode', TRUE)
      ->save();
    $result = $this->executeDataProducer('vgwort', [
      'entity' => $node,
    ]);
    $this->assertNotNull($result);
    $this->assertEquals($node->vgwort_counter_id->value, $result['counterId']);
    $this->assertEquals($node->vgwort_counter_id->url, $result['url']);
    $this->assertEquals('<!-- <img src="\\\\' . $node->vgwort_counter_id->url . '" height="1" width="1" alt=""/> -->', $result['rendered']);

    $term = Term::create([
      'vid' => 'tags',
      'name' => 'Apples',
    ]);
    $term->save();

    $result = $this->executeDataProducer('vgwort', [
      'entity' => $term,
    ]);

    $this->assertNull($result);

    $this->config('vgwort.settings')
      ->set('entity_types', ['taxonomy_term'])
      ->save();

    $this->container->get('entity_type.manager')->getStorage('taxonomy_term')->resetCache();
    $term = Term::load($term->id());

    $result = $this->executeDataProducer('vgwort', [
      'entity' => $term,
    ]);
    $this->assertNotNull($result);
    $this->assertEquals($term->vgwort_counter_id->value, $result['counterId']);
    $this->assertEquals($term->vgwort_counter_id->url, $result['url']);
    $this->assertEquals('<!-- <img src="\\\\' . $term->vgwort_counter_id->url . '" height="1" width="1" alt=""/> -->', $result['rendered']);
  }

}
